Contributing — gentle 0.4.0

# Contributing

Any form of contribution is welcome!

## Workflow

First, get the source code:

    git clone https://git.sysrq.in/gentle

Make some changes and run the tests and the linters:

    tox run

Commit the changes. Your commit message should conform to the following standard:

    file/changed: concice and complete statement of the purpose

    This is the body of the commit message.  The line above is the
    summary.  The summary should be no more than 72 chars long.  The
    body can be more freely formatted, but make it look nice.  Make
    sure to reference any bug reports and other contributors.  Make
    sure the correct authorship appears.

Use git rebase if needed to make commit history look good.

Finally, send a patch to the developer using git send-email:

    git send-email --to=cyber@sysrq.in origin/master

Note

If you prefer GitHub-style workflow, use the mirror repo to send pull requests.

## Adding a new generator

1. Create a new Python file in the `gentle/generators` directory.

2. Implement all `AbstractGenerator` methods.

3. Import your new module in the `gentle/__main__.py` file.

4. Write regression tests for your new generator.

Feel free to copy/paste from existing sources, I do the same.